==> avr-libc-user-manual-2.0.0.tar.bz2: avr-libc-user-manual-2.0.0/search/all_3.js <==
var searchData=
[
  ['combining_20c_20and_20assembly_20source_20files',['Combining C and assembly source files',['../group__asmdemo.html',1,'']]],
  ['calloc',['calloc',['../group__avr__stdlib.html#ga51ac965dacbc9daf922f469bdcfe00c2',1,'calloc(size_t __nele, size_t __size) __ATTR_MALLOC__:&#160;calloc.c'],['../group__avr__stdlib.html#ga51ac965dacbc9daf922f469bdcfe00c2',1,'calloc(size_t nele, size_t size):&#160;calloc.c']]],
  ['cbi',['cbi',['../group__deprecated__items.html#ga08ee265dc07048dbb5a8b6c84551d520',1,'deprecated.h']]],
  ['cbrt',['cbrt',['../group__avr__math.html#ga9dff6efc5e63405ba23afb75eb3e4af0',1,'math.h']]],
  ['cbrtf',['cbrtf',['../group__avr__math.html#gad724f06c46a6f4ad699fece14f219552',1,'math.h']]],
  ['ceil',['ceil',['../group__avr__math.html#ga61470611f23ceef5d3e9cf63d84cd8a7',1,'math.h']]],
  ['ceilf',['ceilf',['../group__avr__math.html#gadb970de70c0549110ae218f6e244c871',1,'math.h']]],
  ['clearerr',['clearerr',['../group__avr__stdio.html#gaaa6d255675688c736c99ebd32f2a7214',1,'clearerr(FILE *__stream):&#160;clearerr.c'],['../group__avr__stdio.html#gaaa6d255675688c736c99ebd32f2a7214',1,'clearerr(FILE *stream):&#160;clearerr.c']]],
  ['cli',['cli',['../group__avr__interrupts.html#ga68c330e94fe121eba993e5a5973c3162',1,'interrupt.h']]],
  ['clock_5fprescale_5fget',['clock_prescale_get',['../power_8h.html#a7154fa3046d3387af8d6c5f489bf7194',1,'power.h']]],
  ['clock_5fprescale_5fset',['clock_prescale_set',['../group__avr__power.html#gae2d32c0c4f18f0019e680354bcc1c3ef',1,'power.h']]],
  ['copysign',['copysign',['../group__avr__math.html#gaaebf29a8e50e6d8f88b6caf697021c86',1,'math.h']]],
  ['copysignf',['copysignf',['../group__avr__math.html#ga1f0a9e760e0cd6faaf9619fd3aebfc3c',1,'math.h']]],
  ['cos',['cos',['../group__avr__math.html#ga542f5e42e0d3b5df63de0e34ec06bb40',1,'math.h']]],
  ['cosf',['cosf',['../group__avr__math.html#gacc171f0e087ed26abd701c827944a43b',1,'math.h']]],
  ['cosh',['cosh',['../group__avr__math.html#ga2ec1caf3ba3b1ba62eccb3eddf029438',1,'math.h']]],
  ['coshf',['coshf',['../group__avr__math.html#ga218c068c47d79563f3fdbcf0ecb45220',1,'math.h']]],
  ['cpufunc_2eh',['cpufunc.h',['../cpufunc_8h.html',1,'']]],
  ['crc16_2eh',['crc16.h',['../crc16_8h.html',1,'']]],
  ['ctime',['ctime',['../group__avr__time.html#ga72a5383fadfbaa033ac36e9e45b0bd6d',1,'ctime(const time_t *timer):&#160;ctime.c'],['../group__avr__time.html#ga72a5383fadfbaa033ac36e9e45b0bd6d',1,'ctime(const time_t *timeptr):&#160;ctime.c']]],
  ['ctime_5fr',['ctime_r',['../group__avr__time.html#ga34fa7766f6b0a8a74a41683693eabad9',1,'ctime_r(const time_t *timer, char *buf):&#160;ctime_r.c'],['../group__avr__time.html#ga34fa7766f6b0a8a74a41683693eabad9',1,'ctime_r(const time_t *timeptr, char *buffer):&#160;ctime_r.c']]],
  ['ctype_2eh',['ctype.h',['../ctype_8h.html',1,'']]],
  ['compiler_20optimization',['Compiler optimization',['../optimization.html',1,'']]]
];

==> avr-libc-user-manual-2.1.0.tar.bz2: avr-libc-user-manual-2.1.0/search/all_3.js <==
var searchData=
[
  ['combining_20c_20and_20assembly_20source_20files',['Combining C and assembly source files',['../group__asmdemo.html',1,'']]],
  ['calloc',['calloc',['../group__avr__stdlib.html#ga51ac965dacbc9daf922f469bdcfe00c2',1,'calloc(size_t __nele, size_t __size) __ATTR_MALLOC__:&#160;calloc.c'],['../group__avr__stdlib.html#ga51ac965dacbc9daf922f469bdcfe00c2',1,'calloc(size_t nele, size_t size):&#160;calloc.c']]],
  ['cbi',['cbi',['../group__deprecated__items.html#ga08ee265dc07048dbb5a8b6c84551d520',1,'deprecated.h']]],
  ['cbrt',['cbrt',['../group__avr__math.html#ga7519d06dd87b989ca32f6fef6fc0d0d8',1,'math.h']]],
  ['cbrtf',['cbrtf',['../group__avr__math.html#ga80bd9a369de03a14bed2b88c9c4da18e',1,'math.h']]],
  ['ccp_5fwrite_5fio',['ccp_write_io',['../group__avr__cpufunc.html#ga8092f4f9ef8cc06e720507cfc38b3e8b',1,'cpufunc.h']]],
  ['ceil',['ceil',['../group__avr__math.html#ga07011f90c603cbcd27ee89cc3c1e15af',1,'math.h']]],
  ['ceilf',['ceilf',['../group__avr__math.html#ga990a991d77569fd88c7e9bee35dd59f1',1,'math.h']]],
  ['clearerr',['clearerr',['../group__avr__stdio.html#gaaa6d255675688c736c99ebd32f2a7214',1,'clearerr(FILE *__stream):&#160;clearerr.c'],['../group__avr__stdio.html#gaaa6d255675688c736c99ebd32f2a7214',1,'clearerr(FILE *stream):&#160;clearerr.c']]],
  ['cli',['cli',['../group__avr__interrupts.html#ga68c330e94fe121eba993e5a5973c3162',1,'interrupt.h']]],
  ['clock_5fprescale_5fget',['clock_prescale_get',['../power_8h.html#a7154fa3046d3387af8d6c5f489bf7194',1,'power.h']]],
  ['clock_5fprescale_5fset',['clock_prescale_set',['../group__avr__power.html#gae2d32c0c4f18f0019e680354bcc1c3ef',1,'power.h']]],
  ['copysignf',['copysignf',['../group__avr__math.html#gacb6ce4b4d73846457683e7db5a285795',1,'math.h']]],
  ['cos',['cos',['../group__avr__math.html#gab96605d13ec0ceeeb379346695e29941',1,'math.h']]],
  ['cosf',['cosf',['../group__avr__math.html#ga34fdf54a9d5e4f631dec030f2648dc0b',1,'math.h']]],
  ['cosh',['cosh',['../group__avr__math.html#gab817cc6cff64210798a943b5467614e2',1,'math.h']]],
  ['coshf',['coshf',['../group__avr__math.html#ga9bc5107830d0ce0daeefda2f3ff48040',1,'math.h']]],
  ['cpufunc_2eh',['cpufunc.h',['../cpufunc_8h.html',1,'']]],
  ['crc16_2eh',['crc16.h',['../crc16_8h.html',1,'']]],
  ['ctime',['ctime',['../group__avr__time.html#ga72a5383fadfbaa033ac36e9e45b0bd6d',1,'ctime(const time_t *timer):&#160;ctime.c'],['../group__avr__time.html#ga72a5383fadfbaa033ac36e9e45b0bd6d',1,'ctime(const time_t *timeptr):&#160;ctime.c']]],
  ['ctime_5fr',['ctime_r',['../group__avr__time.html#ga34fa7766f6b0a8a74a41683693eabad9',1,'ctime_r(const time_t *timer, char *buf):&#160;ctime_r.c'],['../group__avr__time.html#ga34fa7766f6b0a8a74a41683693eabad9',1,'ctime_r(const time_t *timeptr, char *buffer):&#160;ctime_r.c']]],
  ['ctype_2eh',['ctype.h',['../ctype_8h.html',1,'']]],
  ['compiler_20optimization',['Compiler optimization',['../optimization.html',1,'']]]
];
